@@ -9,4 +9,6 @@ echo Compiler messages are redirected to af_compile_results.txt
 echo `date` > af_compile_results.txt
 ./setup.py install --user 2>> af_compile_results.txt
 
+compcount=$( grep "module references __file__" af_compile_results.txt | wc -l )
+echo A total of $compcount modules compiled.
 echo Setup complete. Check af_compile_results.txt for errors.
