@@ -47,6 +47,7 @@
 
 
 
+
 /*--------------------------------------------------------------------------- */
 /* arraylen = The length of the data arrays.
    data = The input data array.
@@ -60,49 +61,69 @@ signed int ceil_float(Py_ssize_t arraylen, int nosimd, float *data, float *datao
 	Py_ssize_t x;
 
 
-
 #if defined(AF_HASSIMD_X86)
-	// SIMD version.
-	if (ignoreerrors && !nosimd && (arraylen >= (FLOATSIMDSIZE * 2))) {
-		if (hasoutputarray) {
-			ceil_float_2_simd(arraylen, data, dataout);
+	signed int errorstate;
+
+	// SIMD version. 
+	if (!nosimd && enoughforsimd(arraylen, FLOATSIMDSIZE)) {
+		// Math error checking disabled.
+		if (ignoreerrors) {
+			if (hasoutputarray) {		
+				ceil_float_2_simd(arraylen, data, dataout);
+			} else {
+				ceil_float_1_simd(arraylen, data);
+			}
 		} else {
-			ceil_float_1_simd(arraylen, data);
+		// Math error checking enabled.
+			if (hasoutputarray) {		
+				errorstate = ceil_float_2_simd_ovfl(arraylen, data, dataout);
+				if (errorstate) {return ARR_ERR_ARITHMETIC;}
+			} else {
+				errorstate = ceil_float_1_simd_ovfl(arraylen, data);
+				if (errorstate) {return ARR_ERR_ARITHMETIC;}
+			}
 		}
-		return ARR_NO_ERR;
-	}
+
+	} else {
 #endif
 
-	// Math error checking disabled.
-	if (ignoreerrors) {
-		if (hasoutputarray) {		
-			for (x = 0; x < arraylen; x++) {
-				dataout[x] = ceilf(data[x]);
+		// Math error checking disabled.
+		if (ignoreerrors) {
+			if (hasoutputarray) {		
+				for (x = 0; x < arraylen; x++) {
+					dataout[x] = ceilf(data[x]);
+				}
+			} else {
+				for (x = 0; x < arraylen; x++) {
+					data[x] = ceilf(data[x]);
+				}
 			}
 		} else {
-			for (x = 0; x < arraylen; x++) {
-				data[x] = ceilf(data[x]);
-			}
-		}
-	} else {
-	// Math error checking enabled.
-		if (hasoutputarray) {		
-			for (x = 0; x < arraylen; x++) {
-				dataout[x] = ceilf(data[x]);
-				if (!isfinite(dataout[x])) {return ARR_ERR_ARITHMETIC;}
-			}
-		} else {
-			for (x = 0; x < arraylen; x++) {
-				data[x] = ceilf(data[x]);
-				if (!isfinite(data[x])) {return ARR_ERR_ARITHMETIC;}
+		// Math error checking enabled.
+			if (hasoutputarray) {		
+				for (x = 0; x < arraylen; x++) {
+					dataout[x] = ceilf(data[x]);
+					if (!isfinite(dataout[x])) {return ARR_ERR_ARITHMETIC;}
+				}
+			} else {
+				for (x = 0; x < arraylen; x++) {
+					data[x] = ceilf(data[x]);
+					if (!isfinite(data[x])) {return ARR_ERR_ARITHMETIC;}
+				}
 			}
 		}
+
+#if defined(AF_HASSIMD_X86)
 	}
+#endif
 
 	return ARR_NO_ERR;
 
 }
 
+/*--------------------------------------------------------------------------- */
+
+
 /*--------------------------------------------------------------------------- */
 /* arraylen = The length of the data arrays.
    data = The input data array.
@@ -116,48 +137,69 @@ signed int ceil_double(Py_ssize_t arraylen, int nosimd, double *data, double *da
 	Py_ssize_t x;
 
 
+#if defined(AF_HASSIMD_X86)
+	signed int errorstate;
+
+	// SIMD version. 
+	if (!nosimd && enoughforsimd(arraylen, DOUBLESIMDSIZE)) {
+		// Math error checking disabled.
+		if (ignoreerrors) {
+			if (hasoutputarray) {		
+				ceil_double_2_simd(arraylen, data, dataout);
+			} else {
+				ceil_double_1_simd(arraylen, data);
+			}
+		} else {
+		// Math error checking enabled.
+			if (hasoutputarray) {		
+				errorstate = ceil_double_2_simd_ovfl(arraylen, data, dataout);
+				if (errorstate) {return ARR_ERR_ARITHMETIC;}
+			} else {
+				errorstate = ceil_double_1_simd_ovfl(arraylen, data);
+				if (errorstate) {return ARR_ERR_ARITHMETIC;}
+			}
+		}
+
+	} else {
+#endif
+
+		// Math error checking disabled.
+		if (ignoreerrors) {
+			if (hasoutputarray) {		
+				for (x = 0; x < arraylen; x++) {
+					dataout[x] = ceil(data[x]);
+				}
+			} else {
+				for (x = 0; x < arraylen; x++) {
+					data[x] = ceil(data[x]);
+				}
+			}
+		} else {
+		// Math error checking enabled.
+			if (hasoutputarray) {		
+				for (x = 0; x < arraylen; x++) {
+					dataout[x] = ceil(data[x]);
+					if (!isfinite(dataout[x])) {return ARR_ERR_ARITHMETIC;}
+				}
+			} else {
+				for (x = 0; x < arraylen; x++) {
+					data[x] = ceil(data[x]);
+					if (!isfinite(data[x])) {return ARR_ERR_ARITHMETIC;}
+				}
+			}
+		}
 
 #if defined(AF_HASSIMD_X86)
-	// SIMD version.
-	if (ignoreerrors && !nosimd && (arraylen >= (DOUBLESIMDSIZE * 2))) {
-		if (hasoutputarray) {
-			ceil_double_2_simd(arraylen, data, dataout);
-		} else {
-			ceil_double_1_simd(arraylen, data);
-		}
-		return ARR_NO_ERR;
 	}
 #endif
 
-	// Math error checking disabled.
-	if (ignoreerrors) {
-		if (hasoutputarray) {
-			for (x = 0; x < arraylen; x++) {
-				dataout[x] = ceil(data[x]);
-			}
-		} else {
-			for (x = 0; x < arraylen; x++) {
-				data[x] = ceil(data[x]);
-			}
-		}
-	} else {
-	// Math error checking enabled.
-		if (hasoutputarray) {
-			for (x = 0; x < arraylen; x++) {
-				dataout[x] = ceil(data[x]);
-				if (!isfinite(dataout[x])) {return ARR_ERR_ARITHMETIC;}
-			}
-		} else {
-			for (x = 0; x < arraylen; x++) {
-				data[x] = ceil(data[x]);
-				if (!isfinite(data[x])) {return ARR_ERR_ARITHMETIC;}
-			}
-		}
-	}
 	return ARR_NO_ERR;
 
 }
 
+/*--------------------------------------------------------------------------- */
+
+
 /*--------------------------------------------------------------------------- */
 
 /* The wrapper to the underlying C function */
@@ -242,7 +284,7 @@ Call formats: \n\
     ceil(array1, outparray) \n\
     ceil(array1, maxlen=y) \n\
     ceil(array1, matherrors=False)) \n\
-    ceil(array, nosimd=False) \n\\n\
+    ceil(array, nosimd=False) \n\
 \n\
 * array1 - The first input data array to be examined. If no output \n\
   array is provided the results will overwrite the input data. \n\
@@ -255,6 +297,7 @@ Call formats: \n\
   default is false. \n\
 * nosimd - If True, SIMD acceleration is disabled. This parameter is \n\
   optional. The default is FALSE.  \n\
+\
 ");
 
 
